/*
Copyright 2017 Google Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

'use strict';

var videoElement = document.querySelector('video#camera-video');
var audioSelect = document.querySelector('select#audioSource');
var videoSelect = document.querySelector('select#videoSource');

audioSelect.onchange = getStream;
videoSelect.onchange = getStream;

getStream().then(getDevices).then(gotDevices);

function getDevices() {
  // AFAICT in Safari this only gets default devices until gUM is called :/
  return navigator.mediaDevices.enumerateDevices();
}

function gotDevices(deviceInfos) {
  window.deviceInfos = deviceInfos; // make available to console
  console.log('Available input and output devices:', deviceInfos);
  for (const deviceInfo of deviceInfos) {
    const option = document.createElement('option');
    option.value = deviceInfo.deviceId;
    if (deviceInfo.kind === 'audioinput') {
      option.text = deviceInfo.label || `Microphone ${audioSelect.length + 1}`;
      audioSelect.appendChild(option);
    } else if (deviceInfo.kind === 'videoinput') {
      option.text = deviceInfo.label || `Camera ${videoSelect.length + 1}`;
      videoSelect.appendChild(option);
    }
  }

  
  
  

  var product = false;

  var canvas2d = document.getElementById('canvas');

  var elementToPlay = document.getElementById('facebook-video');

  var elementToRecord = document.getElementById('video-container');
  canvas2d.width = elementToRecord.clientWidth;
  canvas2d.height = elementToRecord.clientHeight;

  var context = canvas2d.getContext('2d');

  var video = document.getElementById('camera-video');

  var divProduct1 = document.getElementById('divProduct1');
  var divProduct2 = document.getElementById('divProduct2'); 

  var buttonProduct1 = document.getElementById('showProduct1');
  buttonProduct1.addEventListener("click", function() {
    html2canvas(divProduct1).then(function(canvas) {
      product = canvas;
    });
  });
  var buttonProduct2 = document.getElementById('showProduct2');
  buttonProduct2.addEventListener("click", function() {
    html2canvas(divProduct2).then(function(canvas) {
      product = canvas;
    });
  });

  setInterval(function() {
    context.clearRect(0, 0, canvas2d.width, canvas2d.height);
    context.save();

    context.drawImage(video, 0, 0, canvas2d.width, canvas2d.height);

    if (product) {
      context.drawImage(product, 0, 0, 100, 50);
    }

    context.restore();
  }, 1);

  var canvasStream = canvas.captureStream(25);
  elementToPlay.srcObject = canvasStream;
}

function getStream() {
  if (window.stream) {
    window.stream.getTracks().forEach(track => {
      track.stop();
    });
  }
  const audioSource = audioSelect.value;
  const videoSource = videoSelect.value;
  const constraints = {
    audio: {deviceId: audioSource ? {exact: audioSource} : undefined},
    video: {deviceId: videoSource ? {exact: videoSource} : undefined}
  };
  return navigator.mediaDevices.getUserMedia(constraints).
    then(gotStream).catch(handleError);
}

function gotStream(stream) {
  window.stream = stream; // make stream available to console
  audioSelect.selectedIndex = [...audioSelect.options].
    findIndex(option => option.text === stream.getAudioTracks()[0].label);
  videoSelect.selectedIndex = [...videoSelect.options].
    findIndex(option => option.text === stream.getVideoTracks()[0].label);
  videoElement.srcObject = stream;
}

function handleError(error) {
  console.error('Error: ', error);
}